/**
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 *
 * @format
 */
import { ImageRequireSource } from 'react-native';
/**
 * An ML model can be loaded from three different sources, and must be one of
 * the following options:
 *
 * * url to a model file (e.g., https://example.com/my_model.ptl)
 * * path to a local model file (e.g., /data/0/some/path/my_model.ptl)
 * * a path in the JavaScript bundle (e.g., `require('./my_model.ptl')`)
 */
export declare type ModelPath = string | ImageRequireSource;
export declare type ModelInfo = {
    name: string;
    model: ModelPath;
    vocab?: string;
};
/**
 * Checks if the passed in model path is a string or a resolvable asset source.
 * In case the path is a string it will be used as a URI. If it is a resolvable
 * asset source, it will resolve the asset source and get its URI.
 *
 * @param modelPath The model path as require or uri (i.e., `require`).
 * @returns A URI to resolve the model.
 */
export declare function getModelUri(modelPath: ModelPath): string;
